@@ -8,6 +8,8 @@ def to_markdown(html_text):
         return ""
 
     html_text = html_text.replace("$$$", "$")
+    # html_text = html_text.replace("&thinsp;", " ")
+    html_text = html_text.replace(" ", " ") # &thinsp;
     soup = BeautifulSoup(html_text, 'html.parser')
 
     # img tag must be inside <p> tag
