@@ -274,8 +274,8 @@ class TestcaseService:
         name = ""
         if inside_archive_file:
             with ZipFile(testcase_file, 'r') as myzip:
-                fi = myzip.open(inside_archive_file)
-                lines = fi.read().decode("utf-8").split("\n")
+                fi = myzip.open(inside_archive_file, "r")
+                lines = [line.decode("utf-8") for line in fi.readlines()]
         else:
             with open(testcase_file, 'r', encoding="utf-8") as fi:
                 lines = fi.readlines()
@@ -543,7 +543,7 @@ if __name__ == "__main__":
     # testcase_file = r"D:\projects\ucode\ucode-cli\ucode\services\testcase\sample_testcases\cms\cms_sample_nested.zip"
 
     # testcase_file = r"D:\projects\ucode\ucode-cli\ucode\services\testcase\sample_testcases\bridge.zip"
-    testcase_file = r"D:\projects\ucode\ucode-cli\ucode\services\testcase\sample_testcases\ucode\testcases.zip"
+    testcase_file = r"D:\projects\ucode\ucode-cli\ucode\services\testcase\sample_testcases\ucode\testcases-linux.zip"
     testcases = TestcaseService.load_testcases(testcase_file)
     print(testcases)
     print("Count: ", len(testcases))
