@@ -655,6 +655,33 @@ class UCode:
         else:
             raise Exception("Cannot create chapter:" + json.dumps(res))
 
+    def create_blog(self, title, slug=None, content_format="markdown",
+                    content="", short_description="", status="published"):
+        if not slug:
+            slug = make_slug(title)
+
+        data = {
+            "short_description": short_description,
+            "content": content,
+            "title": title,
+            "content_format": content_format,
+            "slug": slug,
+            "status": status,
+        }
+
+        url = self.get_api_url(f"/blog-posts")
+
+        response = self.s.post(url, json=data, headers=self._headers)
+        print(response.status_code)
+        # print(response.text)
+        res = response.json()
+        print(res)
+        if not res['success']:
+            raise Exception("Cannot blog:" + json.dumps(res))
+
+        blog_id = res['data']['id']
+        return blog_id
+
     def create_lesson_item(self, course_id, chapter_id, lesson_name, slug=None,
                            description="", content="", short_description="",
                            type="video", video_url="",
@@ -1074,7 +1101,7 @@ def add_to_daily_challenge():
     for i, (problem_folder, problem) in enumerate(problems):
         problem = ProblemService.load(problem_folder, load_testcase=True)
         print(i + 1, problem.name, "testcases:", len(problem.testcases), ", sample test:",
-              len(problem.testcases_sample))te
+              len(problem.testcases_sample))
 
         prob_id = ucode.create_problem(problem=problem, xp=-1, score=100)
         ucoin = [500,1000,2000][i]
