@@ -50,6 +50,6 @@ Tôn Thất Tùng"""
 
     # parttern = "c2%s-dp@hanoiedu.vn"
     parttern = "c2%s-tp@hcmedu.vn"
-    for s in schools.split("\n"):
+    for s in schools.splitlines():
         name = unidecode(s).lower().replace(" ", "")
         vio.login(parttern % name, "123456789")
